#!/bin/bash
OUTDIR=/tmp/linux-build
serial=/tmp/logs/serial-$ver.txt
initrd=/tmp/initrd #.gz

kernel=$OUTDIR/arch/x86/boot/bzImage
mkdir -p "$(dirname "$serial")"

ver=$(git describe)

yes = | tr -d '\n' | head -c 30
echo -n '  '
yes '' | make O=$OUTDIR oldconfig >/dev/null || exit 125
date -R
time make O=$OUTDIR bzImage -j16 >/dev/null || exit 125

time qemu-system-x86_64 -enable-kvm -m 1G -kernel $kernel \
-initrd $initrd -monitor none -serial file:$serial \
-append 'console=ttyS0' -nographic

size=$(grep ' Core size: \K[0-9]+' -Po "$serial")
if [ -z "$size" ]; then
	echo "No core size found!"
	exit 125
fi

echo -n "Core size: $size"
if [ $size -lt 300000 ]; then
	# core dump too small!
	echo " (too small)"
	exit 1
else
	echo " (ok)"
	exit 0
fi
